@@ -31,19 +31,21 @@ class action_plugin_fckg_meta extends DokuWiki_Action_Plugin {
    */
   function register(&$controller) {
             $controller->register_hook( 'HTML_EDITFORM_INJECTION', 'AFTER', $this, 'postprocess');    
-            // $controller->register_hook( 'HTML_EDITFORM_OUTPUT', 'BEFORE', $this, 'postprocess');    
             $controller->register_hook( 'TPL_METAHEADER_OUTPUT', 'BEFORE', $this, 'meta_scripts');    
+//$controller->register_hook( 'TPL_METAHEADER_OUTPUT', 'AFTER', $this, 'fck_editor');    
             $controller->register_hook( 'HTML_EDITFORM_INJECTION', 'AFTER', $this, 'preprocess'); 
             $controller->register_hook( 'HTML_EDITFORM_OUTPUT', 'BEFORE', $this, 'insertFormElement');       
+            $controller->register_hook( 'HTML_EDITFORM_OUTPUT', 'AFTER', $this, 'disable_textarea');
             $controller->register_hook('DOKUWIKI_STARTED', 'BEFORE', $this, 'file_type');
 
+           // $controller->register_hook('TPL_ACT_RENDER', 'BEFORE', $this, 'fck_editor');
             $controller->register_hook('TPL_CONTENT_DISPLAY', 'AFTER', $this, 'prevent_output');
   }
 
    
   function meta_scripts(&$event) {
          global  $INFO, $conf;
-       
+      
           if(isset($_REQUEST['do']) && $_REQUEST['do'] == 'edit') return;
           $meta_path = str_replace(':', '/', $INFO['id']);
           $meta_path = $conf['metadir']  . '/' . $meta_path . '_dwpi.meta';
@@ -76,9 +78,8 @@ class action_plugin_fckg_meta extends DokuWiki_Action_Plugin {
    if(is_string($act) && $act != 'edit') {  
         return;
    }
-
  $param = array();
- $this->preprocess($event, $param);
+ $this->preprocess($event, $param);  // create the setDWEditCookie() js function
  $button = array
         (
             '_elem' => 'button',
@@ -88,25 +89,64 @@ class action_plugin_fckg_meta extends DokuWiki_Action_Plugin {
             'class' => 'button',
             'id' => 'edbtn__edit',
             'title' => 'FCK Edit',             
-            'onclick' =>'setDWEditCookie(1, this);'
+      //      'onclick' =>'return setDWEditCookie(1, this);'
         );
 
+     $pos = strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE');
+     if($pos === false) {
+                 $button['onclick'] = 'return setDWEditCookie(1, this);';
+     }
+     else {
+                $button['onmousedown'] = 'return setDWEditCookie(1, this);';
+     }
+
+ 
+ $recovery_action = false;
+ if(isset($_REQUEST['do']))  {  
+     $do = $_REQUEST['do'];
+     if(is_array($do) && array_key_exists('recover', $do)) {
+          $recovery_action = true;
+     }
+     else {
+        if($do == 'recover') {
+            $recovery_action = true;
+        }
+     }
+ }
+ 
+   if($recovery_action) { 
+     $button['title'] = 'Edit Recovered Draft';
+     $button['value'] = 'Edit Recovered Draft';
+     $button['id'] = 'btn_recover';
+     echo "<style type = 'text/css'> #edbtn__save, #edbtn__preview { display: none; } </style>";
+    }
+
+
 /*
   $form = $event->data->_content;
   $event->data->_content=$this->insertArrayIndex($form, $button, 5);
 */
 
    // get position of the submit button in the form.
-$pos = $event->data->findElementByAttribute('type','submit');
-   //inserts HTML data after that position.
-$event->data->insertElement(++$pos,$button);
+    $pos = $event->data->findElementByAttribute('type','submit');
+       //inserts HTML data after that position.
+    $event->data->insertElement(++$pos,$button);
 
-  $event->data->_hidden['mode'] = "";
+      $event->data->_hidden['mode'] = "";
+
+      if($recovery_action) {
+          $event->data->_hidden['recovery'] = "";
+      }
+      else {
+           $event->data->_hidden['do'] = 'edit';
+      }
+    
+      $event->data->_hidden['fckEditor_text'] = '';
+     }
 
- }
 
  function  postprocess(&$event, $param) {	 
-   
+ 
    $act = $event->data;
    if(is_string($act) && $act != 'edit') {  
         return;
@@ -120,12 +160,12 @@ if(isset($_REQUEST['do']) && is_array($_REQUEST['do'])) {
  <br />
  <input id = "fckg_mode_type"  type="hidden" name="mode" value="" />
  <input class="button" id="ebtn__edit"
-  onclick ="setDWEditCookie(1, this);this.form.submit();" 
+  onclick ="return setDWEditCookie(1, this);" 
   type="submit" name="do[edit]" value="FCK Edit" accesskey="d" title="FCK Edit [ALT+E]" tabindex="6"  />
 
 BUT;
 
- return;
+     return;
 }
 
 }
@@ -144,13 +184,33 @@ echo <<<BUT
 <br />
  <input id = "fckg_mode_type"  type="hidden" name="mode" value="" />
  <input class="button" id="ebtn__edit"
-  onclick ="setDWEditCookie(1, this);this.form.submit();" 
+  onclick ="return setDWEditCookie(1, this);" 
   type="submit" name="do[edit]" value="FCK Edit" accesskey="d" title="FCK Edit" [ALT+E]" tabindex="6" />
 
 BUT;
 
   }
 
+ function disable_textarea(&$event, $param) {	 
+ $recovery_action = false;
+ if(isset($_REQUEST['do']))  {  
+     $do = $_REQUEST['do'];
+     if(is_array($do) && array_key_exists('recover', $do)) {
+          $recovery_action = true;
+     }
+     else {
+        if($do == 'recover') {
+            $recovery_action = true;
+        }
+     }
+ }
+ 
+   if($recovery_action) {
+    echo "<script language='javascript'>;\n";
+     echo  "document.getElementById('wiki__text').focus = function() {};";  //otherwise IE complains
+     echo  "document.getElementById('wiki__text').disabled = true; </script>\n";
+   }
+ }
 
  function preprocess(&$event, $param) {	 
     $act = $event->data;
@@ -159,12 +219,43 @@ BUT;
         return;
    }
 
-
+  $this->fck_editor($event, $param);
   echo <<<SCRIPT
     <script language="javascript">
     function setDWEditCookie(which, e) {  
 
+      var dwform = $('dw__editform');
+
+      if(e.id) {
+         if(e.id == 'edbtn__edit' && which == 1) {
+           if(!window.confirm(
+               "You will lose any edits made in this preview window")
+               ) {
  
+                   return false;
+                 }
+         }
+      }
+      if(dwform && dwform.elements && dwform.elements.recovery) {           
+           dwform.elements.recovery.value = dwform.elements.wikitext.value; 
+      }
+         /**
+             The contents of the FCKeditor are saved in a hidden DIV when
+             FCK Preview is clicked
+         */
+      if(dwform && dwform.elements && dwform.elements.fckEditor_text) {           
+            var dom = document.getElementById('fckEd__text');
+            if(dom) {
+               dwform.elements.fckEditor_text.value = dom.innerHTML;  
+              if(dwform.elements.changecheck) {
+                     var parent = dwform.elements.changecheck.parentNode;
+                     parent.removeChild(dwform.elements.changecheck);
+                     parent.removeChild(dwform.elements.sectok);
+                     parent.removeChild(dwform.elements.date);
+              }
+            }
+      }
+      
        var dom = document.getElementById('fckg_mode_type');          
        if(which == 1) {
            document.cookie='FCKW_USE=other;expires=Thu,01-Jan-70 00:00:01 GMT;'
@@ -177,6 +268,7 @@ BUT;
             document.cookie = 'FCKW_USE=_false_;expires=' + nextFCKyear.toGMTString() + ';';    
             dom.value = 'dwiki';        
         }
+         e.form.submit();
     }
     </script>
 SCRIPT;
@@ -186,7 +278,7 @@ SCRIPT;
 
   function file_type(&$event, $param) {	 
        global $ACT, $TEXT;
-
+      
        /* set cookie to pass namespace to FCKeditor's media dialgo */
        $expire = time()+60*60*2;
        setcookie ('FCK_NmSp',$_REQUEST['id'], $expire, '/');               
@@ -198,19 +290,36 @@ SCRIPT;
      
   } 
 
+function fck_editor(&$event) {
+
+  
+    if($_REQUEST['fckEditor_text'] ) {
+        echo "<div id = 'fckEd__text' style='position:absolute; visibility:hidden;'>";   
+        echo $_REQUEST['fckEditor_text'];     
+        echo '</div>';
+    }
+
+
+}
  
 /** 
  *  Insures that textarea is empty when empty DW window is requested
 */
   function prevent_output(&$event) {
      global $ACT;
+
+
      if($ACT != 'edit') return;
 
- 
+
    if(isset($_REQUEST['fckg_bak'])) {    
      echo "<script language='javascript'>;\n";
      echo  "document.getElementById('wiki__text').value = ''; </script>\n";
    }
+   
+   
+   
+
 
   }
 
